==> jc-1.4.0.tar.gz: javax/swing/ScrollPaneLayout__24UIResource.h <==
// public class javax.swing.ScrollPaneLayout$UIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 67ab0de2fcfd518c javax_swing_ScrollPaneLayout
// @dep_class 3f6b1d33f2fd63ce javax_swing_ScrollPaneLayout__24UIResource

// header file dependencies
// @dep_header javax_swing_ScrollPaneLayout

#include "javax/swing/ScrollPaneLayout.h"

#ifndef _JC_javax_swing_ScrollPaneLayout__24UIResource_H_
#define _JC_javax_swing_ScrollPaneLayout__24UIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_refs	_jc_javax_swing_ScrollPaneLayout__24UIResource$sub_refs;
typedef struct _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_nonrefs	_jc_javax_swing_ScrollPaneLayout__24UIResource$sub_nonrefs;
typedef struct _jc_javax_swing_ScrollPaneLayout__24UIResource$refs	_jc_javax_swing_ScrollPaneLayout__24UIResource$refs;
typedef struct _jc_javax_swing_ScrollPaneLayout__24UIResource$nonrefs	_jc_javax_swing_ScrollPaneLayout__24UIResource$nonrefs;
typedef struct _jc_javax_swing_ScrollPaneLayout__24UIResource$object	_jc_javax_swing_ScrollPaneLayout__24UIResource$object;

typedef const struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vmethods	_jc_javax_swing_ScrollPaneLayout__24UIResource$vmethods;
typedef const struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vtable	_jc_javax_swing_ScrollPaneLayout__24UIResource$vtable;
typedef const struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vtype	_jc_javax_swing_ScrollPaneLayout__24UIResource$vtype;

// Constructors
extern void _jc_javax_swing_ScrollPaneLayout__24UIResource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_ScrollPaneLayout__24UIResource$object *);

// Virtual methods structure
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ScrollPaneLayout$vmethods	javax_swing_ScrollPaneLayout;
	_jc_javax_swing_ScrollPaneLayout__24UIResource$vmethods	javax_swing_ScrollPaneLayout__24UIResource;
};

// Vtype
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_ScrollPaneLayout__24UIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$refs {
    _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_refs	javax_swing_ScrollPaneLayout__24UIResource;
    _jc_javax_swing_ScrollPaneLayout$sub_refs	javax_swing_ScrollPaneLayout;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ScrollPaneLayout$sub_nonrefs	javax_swing_ScrollPaneLayout;
    _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_nonrefs	javax_swing_ScrollPaneLayout__24UIResource;
};

// Object instance structure
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$object {
	_jc_javax_swing_ScrollPaneLayout__24UIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ScrollPaneLayout__24UIResource$vtype	*vtype;
	_jc_javax_swing_ScrollPaneLayout__24UIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ScrollPaneLayout__24UIResource$vtype _jc_javax_swing_ScrollPaneLayout__24UIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ScrollPaneLayout__24UIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ScrollPaneLayout__24UIResource$class_object;

#endif	/* _JC_javax_swing_ScrollPaneLayout__24UIResource_H_ */

==> jc-1.4.5.tar.gz: javax/swing/ScrollPaneLayout__24UIResource.h <==
// public class javax.swing.ScrollPaneLayout$UIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 67ab0de2fcfd518c javax_swing_ScrollPaneLayout
// @dep_class 3f6b1d33f2fd63ce javax_swing_ScrollPaneLayout__24UIResource

// header file dependencies
// @dep_header javax_swing_ScrollPaneLayout

#include "javax/swing/ScrollPaneLayout.h"

#ifndef _JC_javax_swing_ScrollPaneLayout__24UIResource_H_
#define _JC_javax_swing_ScrollPaneLayout__24UIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_refs	_jc_javax_swing_ScrollPaneLayout__24UIResource$sub_refs;
typedef struct _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_nonrefs	_jc_javax_swing_ScrollPaneLayout__24UIResource$sub_nonrefs;
typedef struct _jc_javax_swing_ScrollPaneLayout__24UIResource$refs	_jc_javax_swing_ScrollPaneLayout__24UIResource$refs;
typedef struct _jc_javax_swing_ScrollPaneLayout__24UIResource$nonrefs	_jc_javax_swing_ScrollPaneLayout__24UIResource$nonrefs;
typedef struct _jc_javax_swing_ScrollPaneLayout__24UIResource$object	_jc_javax_swing_ScrollPaneLayout__24UIResource$object;

typedef const struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vmethods	_jc_javax_swing_ScrollPaneLayout__24UIResource$vmethods;
typedef const struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vtable	_jc_javax_swing_ScrollPaneLayout__24UIResource$vtable;
typedef const struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vtype	_jc_javax_swing_ScrollPaneLayout__24UIResource$vtype;

// Constructors
extern void _jc_javax_swing_ScrollPaneLayout__24UIResource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_ScrollPaneLayout__24UIResource$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ScrollPaneLayout$vmethods	javax_swing_ScrollPaneLayout;
	_jc_javax_swing_ScrollPaneLayout__24UIResource$vmethods	javax_swing_ScrollPaneLayout__24UIResource;
};

// Vtype
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_ScrollPaneLayout__24UIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$refs {
    _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_refs	javax_swing_ScrollPaneLayout__24UIResource;
    _jc_javax_swing_ScrollPaneLayout$sub_refs	javax_swing_ScrollPaneLayout;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ScrollPaneLayout$sub_nonrefs	javax_swing_ScrollPaneLayout;
    _jc_javax_swing_ScrollPaneLayout__24UIResource$sub_nonrefs	javax_swing_ScrollPaneLayout__24UIResource;
};

// Object instance structure
struct _jc_javax_swing_ScrollPaneLayout__24UIResource$object {
	_jc_javax_swing_ScrollPaneLayout__24UIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ScrollPaneLayout__24UIResource$vtype	*vtype;
	_jc_javax_swing_ScrollPaneLayout__24UIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ScrollPaneLayout__24UIResource$vtype _jc_javax_swing_ScrollPaneLayout__24UIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ScrollPaneLayout__24UIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ScrollPaneLayout__24UIResource$class_object;

#endif	/* _JC_javax_swing_ScrollPaneLayout__24UIResource_H_ */
